import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Address} from './r2-common'
import {R2BillingInfo} from './r2-billinginfo'

const R2Pricing = new Complex({
  profession: String,
  professionId: Number,
  price: String,
  priceMultiplier: Number,
  priceToTesBillingId: Number
})

const schema: Schema = {
  fields: {
    _id: ObjectId,
    parent: {type: ObjectId, mongooseRef: 'Company'},
    parentSfId: {type: String, index: true},
    finderId: {type: Number, index: true},
    sfId: {type: String, index: true},
    name: String,
    fullName: [String],
    sortBy: String,
    tes: [String],
    pricing: [R2Pricing],
    ajoryhma: Number,
    industry: String,
    industries: [String],
    businessId: String,
    hidden: Boolean,
    source: {type: String},
    address: R2Address,
    contact: String,
    searchKeys: {type: [String], index: true},
    workHourRegistrySystem: String,
    commissions: [ObjectId], // Obsolete
    timerGroup: Number,
    salesforce: new Complex({
      billingAddress: R2Address,
      shippingAddress: R2Address
    }),
    billingInfo: [R2BillingInfo],
    integrationPointId: Object,
    customerId: {type: String, index: true},
    additionalIndustrySources: [
      new Complex({
        industry: String,
        source: String,
        details: Object
      })
    ]
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('companyMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Company', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
