import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    personId: ObjectId,
    customerId: String,
    transactionId: String,
    hasContracts: Boolean,
    relevantRecruiters: [ObjectId],
    deleteDate: {type: Date, mongooseDefault: now, mongooseExpires: '7d'},
    name: new Complex({last: String, first: String}),
    email: String,
    phone: String,
    birthDate: Date,
    recordFor: { type: String, enum: ['recruiter', 'support', 'hakijakeskus']},
    deletionType: { type: String, enum: ['preliminary', 'permanent']},
    triggeredBy: { type: String, enum: ['recruiter', 'candidate', 'system', 'admin']},
    commissions: [
      new Complex({
        commission: { type: ObjectId, mongooseRef: 'Commission'},
        pipelineState: String
      })
    ]
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('deletedProfileMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('DeletedProfile', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
