import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    sessionId: {type: String, index: 'unique'},
    expires: {type: Date, mongooseDefault: now, mongooseExpires: '60m'},
    userType: {type: String, enum: ['user', 'contactPerson']},
    userId: ObjectId,
    invalid: Boolean
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('jessionMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('Jession', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
