import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    timestamp: {type: Date, mongooseDefault: now, index: true},
    user: {type: ObjectId, mongooseRef: 'User'},
    industry: String,
    url: String,
    method: String,
    eventType: String,
    details: Object,
    customerId: {type: String, index: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('logLineMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('LogLine', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
