import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    createdAt: {type: Date, mongooseDefault: now},
    commission: {type: ObjectId, mongooseRef: 'Commission', index: true},
    interviewRbnId: String,
    inviter: {type: ObjectId, mongooseRef: 'User'},
    candidates: [{type: ObjectId, mongooseRef: 'Person'}],
    customerId: {type: String, index: true}
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('rbnInviteMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('RbnInvite', schema, 'typescript', { omitExtraExports: true })
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
