import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'
import {R2CandidateFilters} from './r2-filters'


const schema: Schema = {
  fields: {
    _id: ObjectId,
    user: {type: ObjectId, mongooseRef: 'User', index: true},
    notificationsLastSeen: Date,
    lastAccess: Date,

    preferences: new Complex({
      industry: String,
      language: String,
      contractCompany: {type: ObjectId, optional: true},
      profile: {type: ObjectId, optional: true},
      commission: {type: ObjectId, optional: true},
      page: String,
      commissionTab: String,
      commissionSlice: String,
      commissionSearch: String,
      candidateSearch: R2CandidateFilters,
      v: Number
    }),
    commissionOrder: [ObjectId],
    customerId: {type: String, index: true},
    extraRoles: [String]
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('userStatusMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('UserStatus', schema, 'typescript', {omitExtraExports: true})
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
