import {Schema} from '../schema'
import ObjectId from '../object-id'
import Complex from '../complex'
import toMongooseSchema from '../mongoose-output'
import toTypescriptSchema from '../ts-output'
import toJSONSchema from '../json-schema-output'
import now from '../now'
import {R2Author} from './r2-common'

const schema: Schema = {
  fields: {
    _id: ObjectId,
    finderId: {type: Number, index: true},
    externalId: {type: String, index: 'unique-sparse'},
    name: new Complex({last: String, first: String}),
    simplifiedName: new Complex({last: String, first: String}),
    email: String,
    lastAccess: {type: Date},
    windowSize: new Complex({
      outerWidth: Number,
      outerHeight: Number,
      innerWidth: Number,
      innerHeight: Number
    }),
    extraGlobalRoles: [String]
  }
}

export default {
  get mongoose() {
    return toMongooseSchema('userMongooseSchema', schema)
  },
  get typescript() {
    return toTypescriptSchema('User', schema, 'typescript', {omitExtraExports: true})
  },
  get json() {
    return toJSONSchema('ExampleJSONSchema', schema, false)
  }
}
